package com.mobula.sample;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.FrameLayout.LayoutParams;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.duapps.ad.AdError;
import com.duapps.ad.DuAdListener;
import com.duapps.ad.DuNativeAd;
import com.google.android.gms.ads.formats.MediaView;
import com.google.android.gms.ads.formats.NativeAppInstallAdView;
import com.google.android.gms.ads.formats.NativeContentAdView;
import com.mobula.sample.util.ImageLoaderHelper;
import com.nostra13.universalimageloader.core.ImageLoader;

/*
 AdMob 广告专用
 Special Activty for AdMob
 */

public class ShowADCardActivity extends Activity {

    private static final String TAG = "ShowADCardActivity";
    private static final int PID = 11279;
    private static final int DEFAULT_CACHE_SIZE = 2;
    DuNativeAd nativeAd;
    ImageLoader imageLoader;
    private TextView titleView;
    private ImageView iconView;
    private RatingBar ratingView;
    private TextView descView;
    private ImageView bigImgView;
    private MediaView mediaView;
    private TextView btnView;
    private RelativeLayout bigImgContainer;
    private NativeContentAdView contentAdView;
    private NativeAppInstallAdView installAdView;
    private RelativeLayout rl;
    private FrameLayout fl;
    private LayoutParams lp;
    DuAdListener mListener = new DuAdListener() {

        @Override
        public void onError(DuNativeAd ad, AdError error) {
            Log.d(TAG, "onError : " + error.getErrorCode());
        }

        @Override
        public void onClick(DuNativeAd ad) {
            Log.d(TAG, "onClick : click ad");
        }

        @Override
        public void onAdLoaded(final DuNativeAd ad) {
            Log.d("TAG", "onAdLoaded: " + ad.getAdChannelType());
            runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    if (ad != null) {
                        fl.removeAllViews();
                    }
                    Log.d(TAG, "ad 渠道号:  " + ad.getAdChannelType());
                    titleView.setText(ad.getTitle());
                    ratingView.setRating(ad.getRatings());
                    imageLoader.displayImage(ad.getIconUrl(), iconView);
                    imageLoader.displayImage(ad.getImageUrl(), bigImgView);
                    descView.setText(ad.getShortDesc());
                    btnView.setText(ad.getCallToAction());

                    // If the type of Ad is “Admob- AppInstall”, then dynamically use the “NativeAppInstallAdView” provided by Admob
                    //判断广告类型,如果是Admob的AppInstall类型广告,则动态使用Admob提供的NativeAppInstallAdView

                    if (ad.getAdChannelType() == DuNativeAd.CHANNEL_TYPE_AM_INSTALL) {
                        Log.d(TAG, "ad CHANNEL_TYPE_AM_INSTALL++++++++");
                        if (lp == null) {
                            lp = new LayoutParams(LayoutParams.WRAP_CONTENT,
                                    LayoutParams.WRAP_CONTENT);
                        }
                        if (installAdView == null) {
                            installAdView = new NativeAppInstallAdView(ShowADCardActivity.this);
                        }
                        installAdView.setHeadlineView(titleView);
                        installAdView.setIconView(iconView);
                        installAdView.setBodyView(descView);
                        installAdView.setImageView(bigImgView);
                        installAdView.setMediaView(mediaView);
                        installAdView.setStarRatingView(ratingView);
                        installAdView.setCallToActionView(btnView);
                        installAdView.addView(rl, lp);
                        mediaView.setVisibility(View.VISIBLE);
                        bigImgView.setVisibility(View.GONE);
                        fl.addView(installAdView);

                        /* When registering the View of Ad in type  “Admob- AppInstall”, “NativeAppInstallAdView” need to be registered.
                         * Otherwise, clicking the Ad will be failed and the impression of Ad will be invalid.
                         */
                        /*注册admob AppInstall类型广告View的时候,需要注册NativeAppInstallAdView,
                         *否则广告无法点击跳转,此展示无效.
                         */
                        nativeAd.registerViewForInteraction(installAdView);

                    }


                    // If the type of AD is “Admob- Content”, then dynamically use the  “NativeContentAdView” provided by Admob
                    //判断广告类型,如果是admob的content类型广告,则动态使用admob提供的NativeContentAdView

                    else if (ad.getAdChannelType() == DuNativeAd.CHANNEL_TYPE_AM_CONTENT) {
                        Log.d(TAG, "ad CHANNEL_TYPE_AM_CONTENT++++++++");
                        if (lp == null) {
                            lp = new LayoutParams(LayoutParams.WRAP_CONTENT,
                                    LayoutParams.WRAP_CONTENT);
                        }
                        if (contentAdView == null) {
                            contentAdView = new NativeContentAdView(ShowADCardActivity.this);
                        }
                        contentAdView.setHeadlineView(titleView);
                        contentAdView.setLogoView(iconView);
                        contentAdView.setBodyView(descView);
                        contentAdView.setMediaView(mediaView);
                        contentAdView.setCallToActionView(btnView);
                        contentAdView.addView(rl, lp);
                        mediaView.setVisibility(View.VISIBLE);
                        bigImgView.setVisibility(View.GONE);
                        fl.addView(contentAdView);

                        /* When registering the View of Ad in type  “Admob- Content”, “NativeContentAdView” need to be registered.
                         * Otherwise, clicking the Ad will be failed and the impression of Ad will be invalid.
                         */
                        /*注册admob content类型广告View的时候,需要注册NativeContentAdView,
                         *否则广告无法点击跳转,此展示无效.
                         */

                        nativeAd.registerViewForInteraction(contentAdView);
                    }


                    // If the type of Ad is “Facebook” or “DU”, please use the below method to register the View.
                    // 广告类型是DuNativeAd.DAP_NORMAL_AD( FB & DU )的时候,请按下面方式注册广告View.

                    else {
                        mediaView.setVisibility(View.GONE);
                        bigImgView.setVisibility(View.VISIBLE);
                        fl.addView(rl);
                        nativeAd.registerViewForInteraction(bigImgContainer);
                    }

                }
            });
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ad_container_layout);
        fl = (FrameLayout) findViewById(R.id.adlayout);
        initView();

        imageLoader = ImageLoaderHelper.getInstance(getApplicationContext());
        nativeAd = new DuNativeAd(this, PID, DEFAULT_CACHE_SIZE);
        nativeAd.setMobulaAdListener(mListener);

        if (null != nativeAd) {
            nativeAd.load();
        }
    }

    private void initView() {
        rl = (RelativeLayout) getLayoutInflater().inflate(R.layout.ad_card_item_layout, fl, false);
        titleView = (TextView) rl.findViewById(R.id.card_name);
        iconView = (ImageView) rl.findViewById(R.id.card_icon);
        ratingView = (RatingBar) rl.findViewById(R.id.card_rating);
        descView = (TextView) rl.findViewById(R.id.card__des);
        bigImgView = (ImageView) rl.findViewById(R.id.card_image);
        mediaView = (MediaView) rl.findViewById(R.id.card_mediaview);
        btnView = (TextView) rl.findViewById(R.id.card_btn);
        bigImgContainer = (RelativeLayout) rl.findViewById(R.id.big_ad);
    }

    @Override
    protected void onResume() {
        // TODO Auto-generated method stub
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        nativeAd.destory();
    }


}
