package com.mobula.sample

import android.app.Activity
import android.graphics.Bitmap
import android.os.Bundle
import android.os.Handler
import android.text.TextUtils
import android.util.Log
import android.view.View
import com.duapps.ad.AdError
import com.duapps.ad.DuAdDataCallBack
import com.duapps.ad.entity.strategy.NativeAd
import com.duapps.ad.list.AdListArrivalListener
import com.duapps.ad.list.DuNativeAdsManager
import com.mobula.sample.util.ImageLoaderKotlinHelper
import com.nostra13.universalimageloader.core.ImageLoader
import com.nostra13.universalimageloader.core.assist.FailReason
import com.nostra13.universalimageloader.core.listener.ImageLoadingListener
import kotlinx.android.synthetic.main.ad_card.*
import java.util.*

/**
 *
 * @author pangzaifei
 * @version v1.0
 * @date 2019/1/15-16:37
 */
class ListAdKotlinActivity : Activity() {

    private val TAG = "ListAdKotlinActivity"
    private lateinit var imageLoader: ImageLoader
    private lateinit var adsManager: DuNativeAdsManager
    /**
     * ad recommend id 广告推荐位
     */
    private val PID = 10032
    /**
     * cache data size 缓存大小
     */
    private val CACHESZIE = 10

    private val mHandler = Handler()
    private var mPositon = 0
    private var mNativeAD: NativeAd? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.ad_card)
        initData()
    }

    private fun initData() {
        imageLoader = ImageLoaderKotlinHelper.getInstance(this)
        adsManager = DuNativeAdsManager(this, PID, CACHESZIE)
    }

    override fun onResume() {
        super.onResume()
        adsManager.apply {
            setListener(listener)
            load()
        }
    }

    private val lists = LinkedList<NativeAd>()

    var listener = (object : AdListArrivalListener {
        override fun onAdLoaded(p0: MutableList<NativeAd>?) {
            lists?.clear()
            p0?.forEach {
                lists?.add(it)
            }
            if (lists.size == CACHESZIE) {
                mHandler.removeCallbacksAndMessages(null)
                mHandler.post(mRunnable)

            }
        }

        override fun onAdError(p0: AdError?) {
        }
    })

    private val mRunnable = object : Runnable {
        override fun run() {
            if (mPositon < lists.size) {
                mNativeAD = lists[mPositon]
                mNativeAD?.setMobulaAdListener(callback)
                val url = mNativeAD?.adCoverImageUrl
                if (TextUtils.isEmpty(url)) {
                    showSmallAdView(mNativeAD)
                } else {
                    showBigAdView(mNativeAD)
                }
                mPositon++

            } else {
                mPositon = 0
            }
            mHandler.postDelayed(this, 8000)
        }
    }

    private fun showBigAdView(ad: NativeAd?) {
        small_ad.visibility = View.GONE
        big_ad.visibility = View.VISIBLE
        card_name.text = ad?.adTitle
        card_rating.rating = ad?.adStarRating ?: 4.0f
        imageLoader.displayImage(ad?.adIconUrl, card_icon)
        card__des.text = ""
        card_btn.text = ad?.adCallToAction
        white_bg.visibility = View.GONE
        mNativeAD?.registerViewForInteraction(card_btn)

        imageLoader.displayImage(ad?.adCoverImageUrl, card_image, object : ImageLoadingListener {
            override fun onLoadingComplete(p0: String?, p1: View?, p2: Bitmap?) {
                load_view.visibility = View.GONE

            }

            override fun onLoadingStarted(p0: String?, p1: View?) {
            }

            override fun onLoadingCancelled(p0: String?, p1: View?) {
            }

            override fun onLoadingFailed(p0: String?, p1: View?, p2: FailReason?) {
            }

        })

    }

    private fun showSmallAdView(ad: NativeAd?) {
        small_card_name.text = ad?.adTitle
        small_card_rating.rating = ad?.adStarRating ?: 4.0f
        imageLoader.displayImage(ad?.adIconUrl, small_card_icon)
        small_card__des.text = ad?.adBody
        small_card_btn.text = ad?.adCallToAction
        mNativeAD?.registerViewForInteraction(small_card_btn)

        big_ad.visibility = View.GONE
        small_ad.visibility = View.VISIBLE
        load_view.visibility = View.GONE
        white_bg.visibility = View.GONE
    }

    internal var callback: DuAdDataCallBack = object : DuAdDataCallBack {

        override fun onAdLoaded(data: NativeAd) {}

        override fun onAdError(error: AdError) {}

        override fun onAdClick() {
            Log.d(TAG, "onClick : click list ad")
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        adsManager.setListener(null)
        adsManager.destroy()
    }

}