package com.mobula.sample

import android.app.Activity
import android.graphics.Bitmap
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.View
import com.duapps.ad.AdError
import com.duapps.ad.DuAdListener
import com.duapps.ad.DuNativeAd
import com.mobula.sample.util.ImageLoaderKotlinHelper
import com.nostra13.universalimageloader.core.ImageLoader
import com.nostra13.universalimageloader.core.assist.FailReason
import com.nostra13.universalimageloader.core.listener.ImageLoadingListener
import kotlinx.android.synthetic.main.ad_card.*

/**
 * display the ads page 显示广告页
 *
 * @author mobula team
 */
class ShowAdKotlinActivity : Activity() {

    private val TAG = "ShowAdKotlinActivity"
    /**
     * ad recommend id 广告推荐位
     */
    private val PID = 10032
    /**
     * cache data size 缓存大小
     */
    private val CACHESZIE = 2
    /**
     * mobula ad data mobula广告数据类
     */
    private var nativeAd: DuNativeAd? = null
    private var imageLoader: ImageLoader? = null

    internal var mListener: DuAdListener = object : DuAdListener {

        override fun onError(ad: DuNativeAd, error: AdError) {
            Log.d(TAG, "onError : ${error.errorCode}")
        }

        override fun onClick(ad: DuNativeAd) {
            Log.d(TAG, "onClick : click ad")
        }

        override fun onAdLoaded(ad: DuNativeAd) {
            Log.d(TAG, "onAdLoaded : ${ad.title}")

            runOnUiThread {
                val url = ad.imageUrl
                if (TextUtils.isEmpty(url)) {
                    showSmallAdView(ad)
                } else {
                    showBigAdView(ad)
                }
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.ad_card)
        initData()
    }

    /**
     * initialize the data method 初始化数据
     */
    private fun initData() {
        imageLoader = ImageLoaderKotlinHelper.getInstance(applicationContext)
        nativeAd = DuNativeAd(this, PID, CACHESZIE)
    }

    override fun onResume() {
        super.onResume()
        if (nativeAd != null) {
            nativeAd!!.setMobulaAdListener(mListener)
            nativeAd!!.load()
        }
    }


    /**
     * show small ad 显示小图广告
     *
     * @param ad
     */
    private fun showSmallAdView(ad: DuNativeAd) {
        small_card_name.text = ad.title
        small_card_rating.rating = ad.ratings
        imageLoader?.displayImage(ad.iconUrl, small_card_icon!!)
        small_card__des.text = ad.shortDesc
        small_card_btn.text = ad.callToAction
        nativeAd?.registerViewForInteraction(small_card_btn)

        big_ad.visibility = View.GONE
        small_ad.visibility = View.VISIBLE
        load_view.visibility = View.GONE
        white_bg.visibility = View.GONE
    }

    /**
     * show big ad 显示大图广告
     *
     * @param ad
     */
    private fun showBigAdView(ad: DuNativeAd) {
        small_ad.visibility = View.GONE
        big_ad.visibility = View.VISIBLE

        card_name.text = ad.title
        card_rating.rating = ad.ratings
        imageLoader?.displayImage(ad.iconUrl, card_icon)
        card__des.text = ""
        card_btn.text = ad.callToAction
        white_bg.visibility = View.GONE
        nativeAd?.registerViewForInteraction(card_btn)
        imageLoader?.displayImage(ad.imageUrl, card_image,
                object : ImageLoadingListener {

                    override fun onLoadingStarted(paramString: String, paramView: View) {}

                    override fun onLoadingFailed(paramString: String, paramView: View,
                                                 paramFailReason: FailReason) {
                    }

                    override fun onLoadingComplete(paramString: String,
                                                   paramView: View, paramBitmap: Bitmap) {
                        load_view.visibility = View.GONE

                    }

                    override fun onLoadingCancelled(paramString: String,
                                                    paramView: View) {
                    }
                })
    }
}
